MethodChannelSuperWebview class

Inheritance

Constructors

MethodChannelSuperWebview()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildWidget({required BuildContext context, required SuperWebViewController controller, String? initialUrl, Map<String, dynamic>? creationParams, void onPlatformViewCreated(int id)?}) Widget
override
createPlatformCookieManager() PlatformCookieManager
override
createPlatformWebViewController(int id) PlatformWebViewController
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited