NavigationDelegate class

Constructors

const

Properties

hashCode int
The hash code for this object.
no setterinherited
onLoadResource → void Function(String url)?
final
onNavigationRequest FutureOr<NavigationDecision> Function(NavigationRequest request)?
final
onPageFinished → void Function(String url)?
final
onPageStarted → void Function(String url)?
final
onProgress → void Function(int id)?
final
onReceivedServerTrustAuthRequest FutureOr<ServerTrustAuthResponse?> Function(ServerTrustChallenge challenge)?
final
onRenderProcessGone → void Function(RenderProcessGoneDetail detail)?
final
onUrlHashChanged → void Function(String url)?
final
onWebResourceError → void Function(WebResourceError error)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited